@@ -18,7 +18,7 @@
   environment variable for CML_PATH in your shell or in your
   codec2/octave/.octaverc file:
 
-    setenv("CML_PATH","../build_linux/cml")
+    setenv("CML_PATH",sprintf("%s/codec2/build_linux/cml",getenv("HOME")))
 #}
 
 1;
@@ -96,7 +96,7 @@ function [code_param framesize rate] = ldpc_init_user(HRA, modulation, mod_order
     code_param.ldpc_parity_bits_per_frame = framesize - code_param.ldpc_data_bits_per_frame;
     code_param.ldpc_coded_bits_per_frame = framesize;
 
-    % these variables support underfilling frame
+    % these variables support 1's stuffing (not using all data bits to lower code rate)
     code_param.data_bits_per_frame  = code_param.ldpc_data_bits_per_frame;
     code_param.coded_bits_per_frame = code_param.ldpc_coded_bits_per_frame;
     code_param.coded_syms_per_frame = code_param.coded_bits_per_frame/code_param.bits_per_symbol;
@@ -104,23 +104,41 @@ endfunction
 
 
 function [codeword s] = ldpc_enc(data, code_param)
+  if code_param.data_bits_per_frame != code_param.ldpc_data_bits_per_frame
+    % optionally lower the code rate by "1's stuffing" - setting Nunused data bits to 1
+    Nunused = code_param.ldpc_data_bits_per_frame - code_param.data_bits_per_frame;
+    codeword = LdpcEncode([data ones(1,Nunused)], code_param.H_rows, code_param.P_matrix);
+    % remove unused data bits from codeword, as they are known to the receiver and don't need to be transmitted
+    codeword = [ codeword(1:code_param.data_bits_per_frame) codeword(code_param.ldpc_data_bits_per_frame+1:end) ];
+  else
     codeword = LdpcEncode( data, code_param.H_rows, code_param.P_matrix );
-    s = Modulate( codeword, code_param.S_matrix );
+  end
+  s = Modulate( codeword, code_param.S_matrix );
 endfunction
 
 
-function [detected_data paritychecks] = ldpc_dec(code_param, max_iterations, demod_type, decoder_type, r, EsNo, fading)
+function [detected_data paritychecks] = ldpc_dec(code_param, max_iterations, ...
+                                                 demod_type, decoder_type, r, ...
+                                                 EsNo, fading)
+    % handle "1's stuffing" case where we don't use all data bits
+    Nunused = code_param.ldpc_data_bits_per_frame - code_param.data_bits_per_frame;
+
     symbol_likelihood = Demod2D( r, code_param.S_matrix, EsNo, fading);
     
     % initialize the extrinsic decoder input
 
-    input_somap_c = zeros(1, code_param.ldpc_coded_bits_per_frame );
+    input_somap_c = zeros(1, code_param.ldpc_coded_bits_per_frame - Nunused);
     bit_likelihood = Somap( symbol_likelihood, demod_type, input_somap_c );
     
-    input_decoder_c = bit_likelihood(1:code_param.ldpc_coded_bits_per_frame);
+    input_decoder_c = bit_likelihood(1:(code_param.ldpc_coded_bits_per_frame-Nunused));
+    
+    % insert "very likely" LLRs for unused data bits (in 1's stuffing case)
+    input_decoder_c = [input_decoder_c(1:code_param.data_bits_per_frame) ...
+                       100*ones(1,Nunused) ...
+                       input_decoder_c(code_param.data_bits_per_frame+1:end)];
     
     [x_hat paritychecks] = MpDecode( -input_decoder_c, code_param.H_rows, code_param.H_cols, ...
-                              max_iterations, decoder_type, 1, 1);
+                                      max_iterations, decoder_type, 1, 1);
     [mx mx_ind] = max(paritychecks);
     detected_data = x_hat(mx_ind,:);    
 endfunction
