@@ -1,7 +1,7 @@
 % tcohpsk.m
 % David Rowe Oct 2014
 %
-% Octave coherent PSK modem script that hs two modes:
+% Octave coherent PSK modem script that has two modes:
 %
 % i) tests the C port of the coherent PSK modem.  This script loads
 %    the output of unittest/tcohpsk.c and compares it to the output of
@@ -28,13 +28,13 @@
 %  [X] false sync
 %      [X] doesn't sync up on noise (used EsNo = -12)
 %      [X] similar but invalid signal like huge f off
-%  [X] ability to "unsync" when signal dissapears
+%  [X] ability to "unsync" when signal disappears
 %  [ ] some calibrated tests against FreeDV 1600
 %      + compare sound quality at various Es/Nos
 %  [ ] sync
 %      + set some req & implement
 %      [ ] way to handle eom w/o nasties
-%          + like mute ouput when signal has gone or v low snr
+%          + like mute output when signal has gone or v low snr
 %          + instantaneous snr
 %  [X] ssb tx filter with 3dB passband ripple
 %      + diverisity helped for AWGN BER 0.024 down to 0.016
@@ -201,7 +201,7 @@ acohpsk.Ns               = 4;
 acohpsk.coh_en           = 1;
 acohpsk.Nd               = Nd;
 acohpsk.modulation       = 'qpsk';
-acohpsk.do_write_pilot_file = 1;      % enable this to dump pilot symbols to C .h file, e.g. if frame params change
+acohpsk.do_write_pilot_file = 0;      % enable this to dump pilot symbols to C .h file, e.g. if frame params change
 acohpsk = symbol_rate_init(acohpsk);
 acohpsk.Ndft = 1024;
 acohpsk.f_est = afdmdv.Fcentre;
@@ -254,10 +254,12 @@ acohpsk.f_fine_est = 0;
 acohpsk.ct = 4;
 acohpsk.ftrack_en = ftrack_en;
 
-[spread spread_2ms hf_gain] = init_hf_model(Fs, frames*acohpsk.Nsymbrowpilot*afdmdv.M);
-hf_n = 1;
-nhfdelay = floor(hf_delay_ms*Fs/1000);
-ch_fdm_delay = zeros(1, acohpsk.Nsymbrowpilot*M + nhfdelay);
+if fading_en
+  [spread spread_2ms hf_gain] = init_hf_model(Fs, frames*acohpsk.Nsymbrowpilot*afdmdv.M);
+  hf_n = 1;
+  nhfdelay = floor(hf_delay_ms*Fs/1000);
+  ch_fdm_delay = zeros(1, acohpsk.Nsymbrowpilot*M + nhfdelay);
+end
 
 % simulated SSB tx filter
 
@@ -281,7 +283,7 @@ for f=1:frames
 
   tx_bits_log = [tx_bits_log tx_bits];
 
-  [tx_symb tx_bits] = bits_to_qpsk_symbols(acohpsk, tx_bits, [], []);
+  [tx_symb tx_bits] = bits_to_qpsk_symbols(acohpsk, tx_bits, []);
   tx_symb_log = [tx_symb_log; tx_symb];
   
   tx_fdm_frame = [];
@@ -697,7 +699,7 @@ end
 
 
 % function to write C header file of noise samples so C version gives
-% extactly the same results
+% exactly the same results
 
 function write_noise_file(uvnoise_log)
 
