@@ -28,114 +28,111 @@
 #ifndef __COMP_PRIM__
 #define __COMP_PRIM__
 
+#include <math.h>
+
 /*---------------------------------------------------------------------------*\
 
                                FUNCTIONS
 
 \*---------------------------------------------------------------------------*/
 
-inline static COMP cneg(COMP a)
-{
-    COMP res;
+inline static COMP cneg(COMP a) {
+  COMP res;
 
-    res.real = -a.real;
-    res.imag = -a.imag;
+  res.real = -a.real;
+  res.imag = -a.imag;
 
-    return res;
+  return res;
 }
 
-inline static COMP cconj(COMP a)
-{
-    COMP res;
+inline static COMP cconj(COMP a) {
+  COMP res;
 
-    res.real = a.real;
-    res.imag = -a.imag;
+  res.real = a.real;
+  res.imag = -a.imag;
 
-    return res;
+  return res;
 }
 
-inline static COMP cmult(COMP a, COMP b)
-{
-    COMP res;
+inline static COMP cmult(COMP a, COMP b) {
+  COMP res;
 
-    res.real = a.real*b.real - a.imag*b.imag;
-    res.imag = a.real*b.imag + a.imag*b.real;
+  res.real = a.real * b.real - a.imag * b.imag;
+  res.imag = a.real * b.imag + a.imag * b.real;
 
-    return res;
+  return res;
 }
 
-inline static COMP fcmult(float a, COMP b)
-{
-    COMP res;
+inline static COMP fcmult(float a, COMP b) {
+  COMP res;
 
-    res.real = a*b.real;
-    res.imag = a*b.imag;
+  res.real = a * b.real;
+  res.imag = a * b.imag;
 
-    return res;
+  return res;
 }
 
-inline static COMP cadd(COMP a, COMP b)
-{
-    COMP res;
+inline static COMP cadd(COMP a, COMP b) {
+  COMP res;
 
-    res.real = a.real + b.real;
-    res.imag = a.imag + b.imag;
+  res.real = a.real + b.real;
+  res.imag = a.imag + b.imag;
 
-    return res;
+  return res;
 }
 
-inline static float cabsolute(COMP a)
-{
-    return sqrtf((a.real * a.real) + (a.imag * a.imag) );
+inline static float cabsolute(COMP a) {
+  return sqrtf((a.real * a.real) + (a.imag * a.imag));
 }
 
 /*
  * Euler's formula in a new convenient function
  */
-inline static COMP comp_exp_j(float phi){
-    COMP res;
-    res.real = cosf(phi);
-    res.imag = sinf(phi);
-    return res;
+inline static COMP comp_exp_j(float phi) {
+  COMP res;
+  res.real = cosf(phi);
+  res.imag = sinf(phi);
+  return res;
 }
 
 /*
  * Quick and easy complex 0
  */
-inline static COMP comp0(){
-    COMP res;
-    res.real = 0;
-    res.imag = 0;
-    return res;
+inline static COMP comp0() {
+  COMP res;
+  res.real = 0;
+  res.imag = 0;
+  return res;
 }
 
 /*
  * Quick and easy complex subtract
  */
-inline static COMP csub(COMP a, COMP b){
-    COMP res;
-    res.real = a.real-b.real;
-    res.imag = a.imag-b.imag;
-    return res;
+inline static COMP csub(COMP a, COMP b) {
+  COMP res;
+  res.real = a.real - b.real;
+  res.imag = a.imag - b.imag;
+  return res;
 }
 
 /*
  * Compare the magnitude of a and b. if |a|>|b|, return true, otw false.
  * This needs no square roots
  */
-inline static int comp_mag_gt(COMP a,COMP b){
-    return ((a.real*a.real)+(a.imag*a.imag)) > ((b.real*b.real)+(b.imag*b.imag));
+inline static int comp_mag_gt(COMP a, COMP b) {
+  return ((a.real * a.real) + (a.imag * a.imag)) >
+         ((b.real * b.real) + (b.imag * b.imag));
 }
 
 /*
  * Normalize a complex number's magnitude to 1
  */
-inline static COMP comp_normalize(COMP a){
-    COMP b;
-    float av = cabsolute(a);
-    b.real = a.real/av;
-    b.imag = a.imag/av;
-    return b;
+inline static COMP comp_normalize(COMP a) {
+  COMP b;
+  float av = cabsolute(a);
+  b.real = a.real / av;
+  b.imag = a.imag / av;
+  return b;
 }
 
 #endif
